@@ -66,7 +66,7 @@ class iexCommon():
     :type external: Boolean or String. Default is False, insert token here to bypass using environment variables.
     """
 
-    def __init__(self, endpoint, symbol, external=False):
+    def __init__(self, section, symbol, endpoint, external=False):
         self.url = f'iexapis.com/stable/{section}/{symbol}/{endpoint}?'
         if not external == False:
             self.token = external
@@ -177,4 +177,13 @@ class iexCommon():
     # Final execution step where token is added and request is made.
     def execute(self):
         self.append_token_to_url()
-        self.make_iex_request()
+        return self.make_iex_request()
+
+#
+# # Standard Usage of Class
+# def iex_endpoint_request_dummy(section, symbol, endpoint, external=False):
+#     """Documentation"""
+#     instance = iexCommon(section, symbol, endpoint, external=external).pre_execute()
+#     # Here is where you would add extra things to the url by directly accessing instance.url
+#     return instance.execute()
+#
